@@ -85,6 +85,9 @@ namespace mars {
 
 
     SelectionTree::~SelectionTree() {
+      if(control->graphics) {
+        control->graphics->removeEventClient(this);
+      }
     }
 
     void SelectionTree::fill(unsigned long id, QTreeWidgetItem *current) {
@@ -467,6 +470,7 @@ namespace mars {
               dropDownValues[1].push_back("invert");
               dropDownValues[1].push_back("osg");
               dropDownValues[1].push_back("iso");
+              dropDownValues[1].push_back("trackball");
 
               dw->setEditPattern(editPattern);
               dw->setFilePattern(filePattern);
@@ -487,6 +491,7 @@ namespace mars {
               else if(mouse == MICHA_CAM) map["mouse"] = "invert";
               else if(mouse == OSG_CAM) map["mouse"] = "osg";
               else if(mouse == ISO_CAM) map["mouse"] = "iso";
+              else if(mouse == TRACKBALL) map["mouse"] = "trackball";
 
               Color c = gw->getClearColor();
               c.toConfigItem(map["clearColor"]);
